@@ -10,17 +10,17 @@ from fastapi_redis_cache.types import ArgType, SigParameters
 ALWAYS_IGNORE_ARG_TYPES = [Response, Request]
 
 
-def get_cache_key(func: Callable, prefix: str, ignore_arg_types: List[ArgType], *args: List, **kwargs: Dict) -> str:
+def get_cache_key(prefix: str, ignore_arg_types: List[ArgType], func: Callable, *args: List, **kwargs: Dict) -> str:
     """Ganerate a string that uniquely identifies the function and values of all arguments.
 
     Args:
-        func (`Callable`): Path operation function for an API endpoint.
         prefix (`str`): Customizable namespace value that will prefix all cache keys.
         ignore_arg_types (`List[ArgType]`): Each argument to the API endpoint function is
             used to compose the cache key by calling `str(arg)`. If there are any keys that
             should not be used in this way (i.e., because their value has no effect on the
             response, such as a `Request` or `Response` object) you can remove them from
             the cache key by including their type as a list item in ignore_key_types.
+        func (`Callable`): Path operation function for an API endpoint.
 
     Returns:
         `str`: Unique identifier for `func`, `*args` and `**kwargs` that can be used as a
@@ -50,10 +50,5 @@ def get_func_args(sig: Signature, *args: List, **kwargs: Dict) -> "OrderedDict[s
 def get_args_str(sig_params: SigParameters, func_args: "OrderedDict[str, Any]", ignore_arg_types: List[ArgType]) -> str:
     """Return a string with the name and value of all args whose type is not included in `ignore_arg_types`"""
     return ",".join(
-        f"{arg}={val}" for arg, val in func_args.items() if not ignore_arg_type(arg, sig_params, ignore_arg_types)
+        f"{arg}={val}" for arg, val in func_args.items() if sig_params[arg].annotation not in ignore_arg_types
     )
-
-
-def ignore_arg_type(arg_name: str, sig_params: SigParameters, ignore_arg_types: List[ArgType]) -> bool:
-    """Check if a function arg is of a type that must NOT be used to construct the cache key."""
-    return any(sig_params[arg_name].annotation is ignore_type for ignore_type in ignore_arg_types)
